@@ -130,7 +130,7 @@ PHP_METHOD(EventHttpRequest, __construct)
 	zend_fcall_info_cache  fcc      = empty_fcall_info_cache;
 	zval                  *zarg     = NULL;
 	struct evhttp_request *req;
-	
+
 
 	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "f|z",
 				&fci, &fcc, &zarg) == FAILURE) {
@@ -355,6 +355,112 @@ PHP_METHOD(EventHttpRequest, getOutputBuffer)
 }
 /* }}} */
 
+#if LIBEVENT_VERSION_NUMBER >= 0x02001100
+/* {{{ proto EventBufferEvent EventHttpRequest::getBufferEvent(void);
+ * Returns EventBufferEvent object on success, otherwise &null. */
+PHP_METHOD(EventHttpRequest, getBufferEvent)
+{
+	php_event_http_req_t     *http_req;
+	struct evhttp_connection *conn;
+	php_event_bevent_t       *bev;
+
+	if (zend_parse_parameters_none() == FAILURE) {
+		return;
+	}
+
+	PHP_EVENT_FETCH_HTTP_REQ(http_req, getThis());
+
+	_check_http_req_ptr(http_req);
+
+	conn = evhttp_request_get_connection(http_req->ptr);
+	if (conn == NULL) {
+		RETURN_NULL();
+	}
+
+	PHP_EVENT_INIT_CLASS_OBJECT(return_value, php_event_bevent_ce);
+	PHP_EVENT_FETCH_BEVENT(bev, return_value);
+
+	bev->bevent = evhttp_connection_get_bufferevent(conn);
+	bev->self = return_value;
+	Z_ADDREF_P(return_value);
+	bev->input = NULL;
+	bev->output = NULL;
+	bev->_internal = 1;
+}
+/* }}} */
+#endif
+
+/* {{{ proto EventHttpConnection EventHttpRequest::getConnection(void);
+ * Returns EventHttpConnection object. 
+ *
+ * Warning! Libevent API allows http request objects not bound to any http connection.
+ * Therefore we can't unambiguously associate EventHttpRequest with EventHttpConnection.
+ * Thus, we construct EventHttpConnection object on-the-fly. Having no information about
+ * base, dns_base and connection-close callback, we just leave these fields unset.
+ *
+ * If somebody finds some way to return full-value EventHttpConnection object,
+ * please don't hesitate to make a pull request.
+ */
+PHP_METHOD(EventHttpRequest, getConnection)
+{
+	php_event_http_req_t     *http_req;
+	struct evhttp_connection *conn;
+	php_event_http_conn_t    *evcon;
+
+	if (zend_parse_parameters_none() == FAILURE) {
+		return;
+	}
+
+	PHP_EVENT_FETCH_HTTP_REQ(http_req, getThis());
+
+	_check_http_req_ptr(http_req);
+
+	conn = evhttp_request_get_connection(http_req->ptr);
+	if (conn == NULL) {
+		RETURN_NULL();
+	}
+
+	PHP_EVENT_INIT_CLASS_OBJECT(return_value, php_event_http_conn_ce);
+	PHP_EVENT_FETCH_HTTP_CONN(evcon, return_value);
+
+	evcon->conn = conn;
+	evcon->self = return_value;
+	Z_ADDREF_P(return_value);
+
+	/* Set in ctor:
+	   evcon->base = NULL;
+	   evcon->dns_base = NULL;
+	   evcon->data_closecb = NULL;
+	   evcon->fci_closecb = NULL;
+	   evcon->fcc_closecb = NULL;
+	*/
+	Z_ADDREF_P(return_value);
+}
+/* }}} */
+
+/* {{{ proto void EventHttpRequest::closeConnection(void);
+ */
+PHP_METHOD(EventHttpRequest, closeConnection)
+{
+	php_event_http_req_t     *http_req;
+	struct evhttp_connection *conn;
+
+	if (zend_parse_parameters_none() == FAILURE) {
+		return;
+	}
+
+	PHP_EVENT_FETCH_HTTP_REQ(http_req, getThis());
+
+	_check_http_req_ptr(http_req);
+
+	conn = evhttp_request_get_connection(http_req->ptr);
+	if (conn == NULL) {
+		return;
+	}
+	evhttp_connection_free(conn);
+}
+/* }}} */
+
 /* {{{ proto void EventHttpRequest::sendError(int error[, string reason = NULL]);
  * Send an HTML error message to the client.
  */
@@ -433,14 +539,13 @@ PHP_METHOD(EventHttpRequest, sendReplyChunk)
 	if (zbuf) {
 		PHP_EVENT_FETCH_BUFFER(b, zbuf);
 		PHP_EVENT_ASSERT(b->buf);
+		evhttp_send_reply_chunk(http_req->ptr, b->buf);
 	}
-
-	evhttp_send_reply_chunk(http_req->ptr, b->buf);
 }
 /* }}} */
 
 /* {{{ proto void EventHttpRequest::sendReplyEnd(void);
- * Complete a chunked reply, freeing the request as appropriate. 
+ * Complete a chunked reply, freeing the request as appropriate.
  */
 PHP_METHOD(EventHttpRequest, sendReplyEnd)
 {
@@ -496,7 +601,7 @@ PHP_METHOD(EventHttpRequest, sendReplyStart)
  *
  * Cancels an ongoing HTTP request. The callback associated with this request
  * is not executed and the request object is freed. If the request is currently
- * being processed, e.g. it is ongoing, the corresponding EventHttpConnection 
+ * being processed, e.g. it is ongoing, the corresponding EventHttpConnection
  * object is going to get reset.
  *
  * A request cannot be canceled if its callback has executed already. A request
